
from .base import InscricaoEstadual
class InscricaoEstadualAC(InscricaoEstadual):
    '''
    Classe para verificação da inscrição estadual do Acre.
    '''
    def is_valid(self):
        if len(self.inscricao) != 13 or not self.inscricao.isdigit():
            return False
        if not self.inscricao.startswith('01'):
            return False
        pesos_1 = [4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2]
        pesos_2 = [5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2]
        soma = sum(int(digito) * peso for digito, peso in zip(self.inscricao[:-2], pesos_1))
        resto = soma % 11
        primeiro_digito_verificador = 11 - resto if resto > 1 else 0
        if primeiro_digito_verificador != int(self.inscricao[-2]):
            return False
        soma = sum(int(digito) * peso for digito, peso in zip(self.inscricao[:-1], pesos_2))
        resto = soma % 11
        segundo_digito_verificador = 11 - resto if resto > 1 else 0
        return segundo_digito_verificador == int(self.inscricao[-1])



from .base import InscricaoEstadual
class InscricaoEstadualSP(InscricaoEstadual):
    '''
    Classe para verificação da inscrição estadual de São Paulo.
    '''

    def is_valid(self):
        if self.inscricao.startswith("P"):
            return self._validar_produtor_rural()
        else:
            return self._validar_industrial_comerciante()

    def _validar_industrial_comerciante(self):
        if len(self.inscricao) != 12 or not self.inscricao.isdigit():
            return False

        # Cálculo do primeiro dígito verificador
        pesos = [1, 3, 4, 5, 6, 7, 8, 10]
        soma = sum(int(digito) * peso for digito, peso in zip(self.inscricao[:8], pesos))
        primeiro_digito_verificador = soma % 11 % 10

        if primeiro_digito_verificador != int(self.inscricao[8]):
            return False

        # Cálculo do segundo dígito verificador
        pesos = [3, 2, 10, 9, 8, 7, 6, 5, 4, 3, 2]
        soma = sum(int(digito) * peso for digito, peso in zip(self.inscricao[:11], pesos))
        segundo_digito_verificador = soma % 11 % 10

        return segundo_digito_verificador == int(self.inscricao[11])

    def _validar_produtor_rural(self):
        if len(self.inscricao) != 13 or not self.inscricao[1:].isdigit():
            return False

        # Cálculo do dígito verificador
        pesos = [1, 3, 4, 5, 6, 7, 8, 10]
        soma = sum(int(digito) * peso for digito, peso in zip(self.inscricao[1:9], pesos))
        digito_verificador = soma % 11 % 10

        return digito_verificador == int(self.inscricao[9])





from .base import InscricaoEstadual
class InscricaoEstadualPE(InscricaoEstadual):
    '''
    Classe para verificação da inscrição estadual de Pernambuco.
    '''
    def is_valid(self):
        if len(self.inscricao) != 14 or not self.inscricao.isdigit():
            return False

        # Primeiro dígito verificador
        pesos = [8, 7, 6, 5, 4, 3, 2]
        soma = sum(int(self.inscricao[i]) * pesos[i] for i in range(7))
        resto = soma % 11
        d1 = 0 if resto <= 1 else 11 - resto

        # Segundo dígito verificador
        pesos = [9, 8, 7, 6, 5, 4, 3, 2]
        soma = sum(int(self.inscricao[i]) * pesos[i] for i in range(8)) + d1 * 2
        resto = soma % 11
        d2 = 0 if resto <= 1 else 11 - resto

        return d1 == int(self.inscricao[13]) and d2 == int(self.inscricao[14])





class InscricaoEstadual:
    '''
    Classe base para verificação de inscrição estadual.
    '''
    def __init__(self, inscricao):
        self.inscricao = inscricao

    def is_valid(self):
        '''
        Método para verificar se a inscrição estadual é válida.
        Deve ser sobrescrito pelas subclasses.
        '''
        raise NotImplementedError("Subclasses devem implementar este método.")



from .base import InscricaoEstadual
class InscricaoEstadualMG(InscricaoEstadual):
    '''
    Classe para verificação da inscrição estadual de Minas Gerais.
    '''
    def is_valid(self):
        if len(self.inscricao) != 13 or not self.inscricao.isdigit():
            return False

        # Primeiro dígito verificador
        numero = self.inscricao[:3] + "0" + self.inscricao[3:11]  # Igualar as casas
        pesos = [1, 2] * 6  # Padrão de pesos alternando entre 1 e 2
        soma = sum(int(numero[i]) * pesos[i] for i in range(12))
        d1 = (10 - (soma % 10)) % 10
        if d1 != int(self.inscricao[11]):
            return False

        # Segundo dígito verificador
        numero = self.inscricao[:12]  # Utiliza o número incluindo o D1
        pesos = [2, 3, 4, 5, 6, 7, 8, 9, 10, 11] * 2  # Padrão de pesos
        soma = sum(int(numero[i]) * pesos[i] for i in range(12))
        resto = soma % 11
        d2 = 0 if resto <= 1 else 11 - resto

        return d2 == int(self.inscricao[12])



from .base import InscricaoEstadual
class InscricaoEstadualGO(InscricaoEstadual):
    '''
    Classe para verificação da inscrição estadual de Goiás.
    '''
    def is_valid(self):
        if len(self.inscricao) != 9 or not self.inscricao.isdigit():
            return False

        base_inscricao = self.inscricao[:-1]  # Exclui o dígito verificador
        digito_verificador = int(self.inscricao[-1])
        pesos = [9, 8, 7, 6, 5, 4, 3, 2]
        soma = sum(int(digito) * peso for digito, peso in zip(base_inscricao, pesos))
        resto = soma % 11
        if resto == 0 or resto == 1:
            digito_calculado = 0
        else:
            digito_calculado = 11 - resto

        return digito_calculado == digito_verificador



from .acre import InscricaoEstadualAC
from .alagoas import InscricaoEstadualAL
from .goias import InscricaoEstadualGO
from .mato_grosso import InscricaoEstadualMT
from .minas_gerais import InscricaoEstadualMG
from .pernambuco import InscricaoEstadualPE
from .sao_paulo import InscricaoEstadualSP


from .base import InscricaoEstadual
class InscricaoEstadualAL(InscricaoEstadual):
    '''
    Classe para verificação da inscrição estadual de Alagoas.
    '''
    def is_valid(self):
        if len(self.inscricao) != 9 or not self.inscricao.isdigit() or not self.inscricao.startswith('24'):
            return False
        pesos = [9, 8, 7, 6, 5, 4, 3, 2]
        soma = sum(int(digito) * peso for digito, peso in zip(self.inscricao[2:-1], pesos))
        produto = soma * 10
        resto = produto - (produto // 11 * 11)
        digito_verificador = 0 if resto == 10 else resto
        return digito_verificador == int(self.inscricao[-1])



from setuptools import setup, find_packages

setup(
    name='sintegraIEValidator',
    version='0.1.6',  # Atualização da versão
    packages=find_packages(),
    license='MIT',
    description='Um validador de inscrição estadual para estados brasileiros.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Seu Nome',
    author_email='seuemail@example.com',
    url='https://github.com/josetiagobispo/sintegra-ie-validator',
    install_requires=[],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.11',
    ],
    keywords='validação inscrição estadual brasil estados',
)

